InMemory

Struct InMemory 

pub struct InMemory { /* private fields */ }
In-memory storage suitable for testing or for opting out of using a cloud storage provider.

Implementations

Source

impl InMemory

pub fn new() -> Self

Create new in-memory storage.

pub fn fork(&self) -> Self

Creates a fork of the store, with the current content copied into the new store.